@@ -8,9 +8,7 @@
 #define IUNIT_H
 
 #include "artikulatecore_export.h"
-#include <QMap>
 #include <QObject>
-#include <QUrl>
 #include <memory>
 
 class QString;
